@@ -127,7 +127,20 @@ void BootMan::install(const QStringList &cmdextra)
     }
 
     bool efivars_ismounted = false;
-    if (gui.boxBoot->isChecked() && gui.radioBootESP->isChecked()) {
+    const bool replacementMode = gui.radioReplace->isChecked();
+    const bool espRequested = gui.boxBoot->isChecked() && gui.radioBootESP->isChecked();
+    const PartMan::Device *espdev = nullptr;
+    if (espRequested) {
+        espdev = partman.findByMount(u"/boot/efi"_s);
+        if (!espdev) espdev = partman.findByMount(u"/boot"_s);
+    }
+    const bool haveEsp = espdev && espdev->flags.sysEFI;
+    const bool fallbackToMbr = replacementMode && espRequested && !haveEsp;
+    const bool useEsp = espRequested && haveEsp;
+    if (fallbackToMbr) {
+        qDebug() << "ESP not found during replacement, falling back to BIOS/MBR install.";
+    }
+    if (useEsp) {
         const QString &efivars = u"/sys/firmware/efi/efivars"_s;
         if (QFileInfo(efivars).isDir()) {
             efivars_ismounted = proc.exec(u"mountpoint"_s, {u"-q"_s, efivars});
@@ -145,7 +158,7 @@ void BootMan::install(const QStringList &cmdextra)
         // install new Grub now
         const int efisize = core.detectEFI(true);
         const QString &bootdev = "/dev/"_L1 + gui.comboBoot->currentData().toString();
-        if (!gui.radioBootESP->isChecked()) {
+        if (!useEsp) {
             proc.exec(u"grub-install"_s, {u"--target=i386-pc"_s, u"--recheck"_s,
                 u"--no-floppy"_s, u"--force"_s, u"--boot-directory=/mnt/antiX/boot"_s, bootdev});
         } else {
@@ -165,8 +178,6 @@ void BootMan::install(const QStringList &cmdextra)
             QStringList grubinstargs({u"--no-nvram"_s, u"--force-extra-removable"_s,
                 (efisize==32 ? u"--target=i386-efi"_s : u"--target=x86_64-efi"_s),
                 "--bootloader-id="_L1 + loaderID, u"--recheck"_s});
-            const PartMan::Device *espdev = partman.findByMount(u"/boot/efi"_s);
-            if (!espdev) espdev = partman.findByMount(u"/boot"_s);
             QString efiDir;
             if (espdev) {
                 efiDir = espdev->mountPoint();
@@ -180,13 +191,18 @@ void BootMan::install(const QStringList &cmdextra)
 
             // Copy fallback files (not copied above because of --no-nvram switch).
             if (espdev != nullptr) {
-                const QString &espdst = espdev->mountPoint() + "/EFI/"_L1;
-                const QString &espsrc = espdst + loaderID;
-                if (QFile(espsrc + "/fbx64.efi").exists()) {
-                    proc.exec(u"cp"_s, {u"-p"_s, espsrc + "/fbx64.efi"_L1, espdst + "BOOT/"_L1});
+                QString espdst = espdev->mountPoint() + "/EFI/"_L1;
+                QString espsrc = espdst + loaderID;
+                QString fbx64efi = espsrc + "/fbx64.efi";
+                QString debianGrub = espsrc + "/grub.cfg";
+                //file check is on /mnt/antiX as this command does not act in the chroot
+                if (QFile("/mnt/antiX" + fbx64efi).exists()) {
+                    proc.exec(u"cp"_s, {u"-p"_s, fbx64efi, espdst + "BOOT/"_L1});
+                }
+                if (QFile("/mnt/antiX" + debianGrub).exists()){
+                    core.mkpath("/mnt/antiX"_L1 + espdst + "debian/"_L1);
+                    proc.exec(u"cp"_s, {u"-p"_s, debianGrub, espdst + "debian/"_L1});
                 }
-                core.mkpath("/mnt/antiX"_L1 + espdst + "debian/"_L1);
-                proc.exec(u"cp"_s, {u"-p"_s, espsrc + "/grub.cfg"_L1, espdst + "debian/"_L1});
             }
 
             // Update the boot NVRAM variables. Non-critial step so no need to fail.
